// /////////////////////////////////////////////////////////////////////////////
//  RDApplication.h
//  RDAppKit.framework
//
//  Application framework for my apps.
//  Copyright (C) 2004 Robbie Duncan
//
// /////////////////////////////////////////////////////////////////////////////
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// /////////////////////////////////////////////////////////////////////////////
//
/*!
@header RDApplication
@discussion Defines the RDApplication NSApplication subclass.
*/
#import <Foundation/Foundation.h>
#import "RDAKLicenseController.h"
#import "RDAKVersionHistoryController.h"
#import "RDAKUpdateController.h"
#import "RDAKBugsController.h"
//
/*!
@class RDAKApplication
@abstract NSApplication subclass providing extra functionality.
@discussion NSApplication subclass providing functionality to show various standard documents and check for updates online.
*/
@interface RDAKApplication : NSApplication 
{
}
// Initialisation
- (void) finishLaunching;
// UI Action Handlers
/*!
    @method checkForUpdates:
    @abstract Checks for updates on the Internet.
    @discussion Checks for any updates on the Internet.
	@param sender The calling object.
*/
- (IBAction) checkForUpdates:(id) sender;
/*!
	@method showLicense:
	@abstract Shows the license file in a text window.
	@discussion Shows the license file in a text window.  The license file should be called license.txt in the applications bundle.  If this file exists (and the application main object is RDAKApplication) then a Show License menu item will automatically be added to the Help menu.
	@param sender The calling object.
*/
- (IBAction) showLicense:(id) sender;
/*!
	@method showVersionHistory:
	@abstract Shows the version history file in a text window.
	@discussion Shows the version history file in a text window.  The version history file should be called versions.txt in the applications bundle.  If this file exists (and the application main object is RDAKApplication) then a Show Version History menu item will automatically be added to the Help menu.
	@param sender The calling object.
*/
- (IBAction) showVersionHistory:(id) sender;
/*!
	@method showBugs:
	@abstract Shows the known bugs file in a text window.
	@discussion Shows the known bugs file in a text window.  The known bugs file should be called bugs.txt in the applications bundle.  If this file exists (and the application main object is RDAKApplication) then a Show Known Bugs menu item will automatically be added to the Help menu.
	@param sender The calling object.
*/
- (IBAction) showBugs:(id) sender;
//
@end
